@@ -151,10 +151,25 @@ def is_flatpak() -> bool:
     return gajim.IS_FLATPAK
 
 
+def is_flatpak_nightly() -> bool:
+    return gajim.IS_FLATPAK_NIGHTLY
+
+
 def is_portable() -> bool:
     return gajim.IS_PORTABLE
 
 
+def is_ms_store() -> bool:
+    return gajim.IS_MS_STORE
+
+
+def get_default_app_id() -> str:
+    app_id = 'org.gajim.Gajim'
+    if is_flatpak_nightly():
+        return f'{app_id}.Devel'
+    return app_id
+
+
 def is_display(display: Display) -> bool:
     # XWayland reports as Display X11, so try with env var
     is_wayland = os.environ.get('XDG_SESSION_TYPE') == 'wayland'
@@ -448,9 +463,7 @@ def get_transport_name_from_jid(
 
 def jid_is_transport(jid: str) -> bool:
     # if not '@' or '@' starts the jid then it is transport
-    if jid.find('@') <= 0:
-        return True
-    return False
+    return jid.find('@') <= 0
 
 
 def get_jid_from_account(account_name: str) -> str:
