@@ -108,6 +108,7 @@ class Notification(ApplicationEvent):
     sub_type: str | None = None
     sound: str | None = None
     icon_name: str | None = None
+    resource: str | None = None
 
 
 @dataclass
@@ -726,6 +727,15 @@ class MUCRoomDestroyed(ApplicationEvent):
     alternate: JID | None
 
 
+@dataclass
+class MUCUserHatsChanged(ApplicationEvent):
+    name: str = field(init=False, default='muc-user-hats-changed')
+    timestamp: datetime.datetime
+    is_self: bool
+    nick: str
+    hats: list[str] | None
+
+
 @dataclass
 class MUCUserJoined(ApplicationEvent):
     name: str = field(init=False, default='muc-user-joined')
