@@ -1,16 +1,6 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 # Chat Markers (XEP-0333)
 
@@ -18,8 +8,12 @@ from __future__ import annotations
 
 from typing import Any
 
+import datetime as dt
+
+import nbxmpp
 from nbxmpp.namespaces import Namespace
 from nbxmpp.protocol import JID
+from nbxmpp.structs import MessageProperties
 from nbxmpp.structs import StanzaHandler
 
 from gajim.common import app
@@ -29,6 +23,7 @@ from gajim.common.events import ReadStateSync
 from gajim.common.modules.base import BaseModule
 from gajim.common.modules.contacts import BareContact
 from gajim.common.modules.contacts import GroupchatContact
+from gajim.common.storage.archive import models as mod
 from gajim.common.structs import OutgoingMessage
 
 
@@ -49,19 +44,27 @@ class ChatMarkers(BaseModule):
     def _process_chat_marker(self,
                              _client: types.xmppClient,
                              _stanza: Any,
-                             properties: Any) -> None:
+                             properties: MessageProperties) -> None:
 
-        if not properties.is_marker or not properties.marker.is_displayed:
+        if properties.marker is None or not properties.marker.is_displayed:
             return
 
         if properties.type.is_error:
             return
 
+        self._process(properties)
+        raise nbxmpp.NodeProcessed
+
+    def _process(self, properties: MessageProperties) -> None:
+        assert properties.marker is not None
+        assert properties.jid is not None
+
         jid = properties.jid
         if not properties.is_muc_pm:
             jid = properties.jid.new_as_bare()
 
         if properties.type.is_groupchat:
+            assert properties.muc_jid is not None
             contact = self._client.get_module('Contacts').get_contact(
                 properties.muc_jid,
                 groupchat=True)
@@ -96,19 +99,26 @@ class ChatMarkers(BaseModule):
                        properties.jid,
                        properties.marker.id)
 
-        jid = properties.jid
         if not properties.is_muc_pm and not properties.type.is_groupchat:
-            jid = properties.jid.bare
+            if properties.is_mam_message:
+                timestamp = properties.mam.timestamp
+            else:
+                timestamp = properties.timestamp
 
-        app.storage.archive.set_marker(
-            app.get_jid_from_account(self._account),
-            jid,
-            properties.marker.id,
-            'displayed')
+            timestamp = dt.datetime.fromtimestamp(
+                timestamp, dt.timezone.utc)
+
+            marker_data = mod.DisplayedMarker(
+                account_=self._account,
+                remote_jid_=properties.remote_jid,
+                occupant_=None,
+                id=properties.marker.id,
+                timestamp=timestamp)
+            app.storage.archive.insert_object(marker_data)
 
         app.ged.raise_event(
             DisplayedReceived(account=self._account,
-                              jid=jid,
+                              jid=properties.remote_jid,
                               properties=properties,
                               type=properties.type,
                               is_muc_pm=properties.is_muc_pm,
@@ -119,12 +129,8 @@ class ChatMarkers(BaseModule):
                      marker: str,
                      id_: str) -> None:
 
-        typ = 'groupchat' if contact.is_groupchat else 'chat'
-
         message = OutgoingMessage(account=self._account,
                                   contact=contact,
-                                  message=None,
-                                  type_=typ,
                                   marker=(marker, id_),
                                   play_sound=False)
 
