@@ -22,11 +22,13 @@ from gi.repository import Gtk
 
 from gajim.common import app
 from gajim.common.const import AvatarSize
-from gajim.common.helpers import get_file_path_from_dnd_dropped_uri
 from gajim.common.i18n import _
-from gajim.common.image_helpers import scale_with_ratio
+from gajim.common.util.image import scale_with_ratio
+from gajim.common.util.uri import get_file_path_from_dnd_dropped_uri
 
 from gajim.gtk import types
+from gajim.gtk.const import DND_TARGET_FLATPAK
+from gajim.gtk.const import DND_TARGET_URI_LIST
 from gajim.gtk.const import TARGET_TYPE_URI_LIST
 from gajim.gtk.dialogs import ErrorDialog
 from gajim.gtk.filechoosers import AvatarChooserDialog
@@ -64,9 +66,9 @@ class AvatarSelector(Gtk.Box):
         self.get_style_context().add_class('avatar-selector')
 
         if app.is_flatpak():
-            target = 'application/vnd.portal.files'
+            target = DND_TARGET_FLATPAK
         else:
-            target = 'text/uri-list'
+            target = DND_TARGET_URI_LIST
 
         uri_entry = Gtk.TargetEntry.new(
             target, Gtk.TargetFlags.OTHER_APP, TARGET_TYPE_URI_LIST)
