@@ -5,6 +5,7 @@
 from __future__ import annotations
 
 import logging
+import os
 
 import emoji
 from gi.repository import Gdk
@@ -13,11 +14,11 @@ from gi.repository import Gtk
 from gi.repository import Pango
 
 from gajim.common.const import URIType
-from gajim.common.helpers import open_uri
-from gajim.common.helpers import parse_uri
 from gajim.common.styling import BaseHyperlink
 from gajim.common.styling import PlainBlock
 from gajim.common.styling import process_uris
+from gajim.common.util.uri import open_uri
+from gajim.common.util.uri import parse_uri
 
 from gajim.gtk.const import MAX_MESSAGE_LENGTH
 from gajim.gtk.menus import get_conv_action_context_menu
@@ -59,7 +60,10 @@ class MessageLabel(Gtk.Label):
         self.set_xalign(0)
         # WrapMode.WORD_CHAR can cause a segfault
         # https://gitlab.gnome.org/GNOME/pango/-/issues/798
-        self.set_line_wrap_mode(Pango.WrapMode.WORD)
+        if os.environ.get('GAJIM_FORCE_WORD_WRAP'):
+            self.set_line_wrap_mode(Pango.WrapMode.WORD)
+        else:
+            self.set_line_wrap_mode(Pango.WrapMode.WORD_CHAR)
         self.set_track_visited_links(False)
 
         self._account = account
@@ -100,7 +104,6 @@ class MessageLabel(Gtk.Label):
     def print_text_with_styling(self, block: PlainBlock) -> None:
         text = self._build_link_markup(block.text, block.uris)
         self.set_markup(text)
-
         if len(self.get_text()) > MAX_MESSAGE_LENGTH:
             # Limit message styling processing
             return
@@ -108,7 +111,9 @@ class MessageLabel(Gtk.Label):
         self.set_attributes(make_pango_attributes(block))
 
         stripped = text.strip()
-        if emoji.purely_emoji(stripped):
+        # https://github.com/carpedm20/emoji/issues/300
+        # purely_emoji() return True for the empty string
+        if stripped and emoji.purely_emoji(stripped):
             emoji_count = emoji.emoji_count(stripped)
             if emoji_count == 1:
                 classname = 'gajim-single-emoji-msg'
