@@ -1,34 +1,22 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 from __future__ import annotations
 
-import time
-from datetime import datetime
-
 from gi.repository import GdkPixbuf
 from gi.repository import Gtk
 
 from gajim.common import app
 from gajim.common import types
 from gajim.common.const import AvatarSize
-from gajim.common.const import KindConstant
 from gajim.common.events import JingleRequestReceived
 from gajim.common.i18n import _
 from gajim.common.jingle_session import JingleSession
 from gajim.common.modules.contacts import BareContact
-from gajim.common.storage.archive import ConversationRow
+from gajim.common.storage.archive.const import ChatDirection
+from gajim.common.storage.archive.models import Message
+from gajim.common.util.datetime import utc_now
 
 from gajim.gtk.conversation.rows.base import BaseRow
 from gajim.gtk.conversation.rows.widgets import DateTimeLabel
@@ -41,7 +29,7 @@ class CallRow(BaseRow):
                  account: str,
                  contact: types.BareContact,
                  event: JingleRequestReceived | None = None,
-                 db_message: ConversationRow | None = None
+                 message: Message | None = None
                  ) -> None:
         BaseRow.__init__(self, account)
 
@@ -49,26 +37,24 @@ class CallRow(BaseRow):
 
         self._client = app.get_client(account)
 
-        if db_message is not None:
-            timestamp = db_message.time
+        if message is not None:
+            timestamp = message.timestamp
         else:
-            timestamp = time.time()
-        self.timestamp = datetime.fromtimestamp(timestamp)
-        self.db_timestamp = timestamp
+            timestamp = utc_now()
+        self.timestamp = timestamp.astimezone()
+        self.db_timestamp = timestamp.timestamp()
 
         self._contact = contact
         self._event = event
-        self._db_message = db_message
+        self._message = message
 
         self._session: JingleSession | None = None
 
-        if db_message is not None:
-            assert db_message.additional_data is not None
-            sid = db_message.additional_data.get_value('gajim', 'sid')
+        if message is not None and message.call is not None:
             module = self._client.get_module('Jingle')
             self._session = module.get_jingle_session(
-                str(self._contact.jid), sid)
-            self.log_line_id = db_message.log_line_id
+                str(self._contact.jid), message.call.sid)
+            self.pk = message.pk
 
         self._avatar_placeholder = Gtk.Box()
         self._avatar_placeholder.set_size_request(AvatarSize.ROSTER, -1)
@@ -122,8 +108,8 @@ class CallRow(BaseRow):
         assert isinstance(contact, BareContact)
 
         is_self = True
-        if self._db_message is not None:
-            if self._db_message.kind == KindConstant.CALL_INCOMING:
+        if self._message is not None:
+            if self._message.direction == ChatDirection.INCOMING:
                 contact = self._contact
                 is_self = True
             else:
