@@ -44,9 +44,10 @@ from nbxmpp.protocol import JID
 from nbxmpp.structs import DiscoIdentity
 
 from gajim.common import app
-from gajim.common import helpers
 from gajim.common.const import StyleAttr
 from gajim.common.i18n import _
+from gajim.common.util.jid import InvalidFormat
+from gajim.common.util.jid import parse_jid
 
 from gajim.gtk.builder import get_builder
 from gajim.gtk.component_search import ComponentSearch
@@ -496,7 +497,7 @@ class ServiceDiscoveryWindow:
         self._account = account
         self.parent = parent
         if not jid:
-            jid = app.settings.get_account_setting(account, 'hostname')
+            jid = app.get_hostname_from_account(account)
             node = None
 
         self.jid = None
@@ -726,8 +727,8 @@ class ServiceDiscoveryWindow:
             # User selected one of the entries so do auto-visit
             jid = self._ui.address_comboboxtext_entry.get_text()
             try:
-                jid = helpers.parse_jid(jid)
-            except helpers.InvalidFormat as s:
+                jid = parse_jid(jid)
+            except InvalidFormat as s:
                 ErrorDialog(_('Invalid Server Name'), str(s))
                 return
             self.travel(jid, None)
@@ -735,8 +736,8 @@ class ServiceDiscoveryWindow:
     def _on_go_button_clicked(self, widget):
         jid = self._ui.address_comboboxtext_entry.get_text()
         try:
-            jid = helpers.parse_jid(jid)
-        except helpers.InvalidFormat as s:
+            jid = parse_jid(jid)
+        except InvalidFormat as s:
             ErrorDialog(_('Invalid Server Name'),
                         str(s),
                         transient_for=self.window)
@@ -2042,7 +2043,7 @@ class DiscussionGroupsBrowser(AgentBrowser):
 
     def _on_subscribe_button_clicked(self, widget):
         '''
-        Called when 'subscribe' button is pressed. Send subscribtion request
+        Called when 'subscribe' button is pressed. Send subscription request
         '''
         model, iter_ = \
             self.window.services_treeview.get_selection().get_selected()
