@@ -19,17 +19,19 @@ from nbxmpp.protocol import JID
 
 from gajim.common import app
 from gajim.common import types
-from gajim.common.helpers import get_file_path_from_dnd_dropped_uri
 from gajim.common.helpers import load_file_async
 from gajim.common.i18n import _
-from gajim.common.image_helpers import create_thumbnail
-from gajim.common.image_helpers import get_pixbuf_from_data
 from gajim.common.modules.contacts import BareContact
 from gajim.common.preview import PREVIEWABLE_MIME_TYPES
-from gajim.common.preview_helpers import get_icon_for_mime_type
-from gajim.common.preview_helpers import guess_mime_type
+from gajim.common.util.image import create_thumbnail
+from gajim.common.util.image import get_pixbuf_from_data
+from gajim.common.util.preview import get_icon_for_mime_type
+from gajim.common.util.preview import guess_mime_type
+from gajim.common.util.uri import get_file_path_from_dnd_dropped_uri
 
 from gajim.gtk.builder import get_builder
+from gajim.gtk.const import DND_TARGET_FLATPAK
+from gajim.gtk.const import DND_TARGET_URI_LIST
 from gajim.gtk.const import TARGET_TYPE_URI_LIST
 from gajim.gtk.filechoosers import FileChooserDialog
 from gajim.gtk.resource_selector import ResourceSelector
@@ -81,9 +83,9 @@ class FileTransferSelector(Gtk.Box):
                   'files to.') % self._contact.name)
 
         if app.is_flatpak():
-            target = 'application/vnd.portal.files'
+            target = DND_TARGET_FLATPAK
         else:
-            target = 'text/uri-list'
+            target = DND_TARGET_URI_LIST
 
         uri_entry = Gtk.TargetEntry.new(
             target, Gtk.TargetFlags.OTHER_APP, TARGET_TYPE_URI_LIST)
