@@ -12,7 +12,7 @@ REPO_DIR = Path(__file__).resolve().parent.parent
 
 INIT = REPO_DIR / 'gajim' / '__init__.py'
 FLATPAK = REPO_DIR / 'flatpak' / 'org.gajim.Gajim.yaml'
-APPDATA = REPO_DIR / 'data' / 'org.gajim.Gajim.appdata.xml.in'
+APPDATA = REPO_DIR / 'data' / 'org.gajim.Gajim.metainfo.xml.in'
 CHANGELOG = REPO_DIR / 'ChangeLog'
 
 VERSION_RX = r'\d+\.\d+\.\d+'
