@@ -2,7 +2,7 @@ import unittest
 
 from gajim.common import app  # noqa: F401  (avoid circular imports)
 from gajim.common.const import XmppUriQuery
-from gajim.common.helpers import _xmpp_query_type_handlers
+from gajim.common.util.uri import _xmpp_query_type_handlers
 
 
 class Test(unittest.TestCase):
