@@ -114,6 +114,7 @@ sentry-sdk
 emoji
 winrt-Windows.ApplicationModel
 winrt-Windows.Foundation
+winrt-Windows.Storage
 winrt-Windows.UI
 winrt-Windows.UI.ViewManagement
 windows-toasts
@@ -145,6 +146,7 @@ function install_gajim {
 
     cd ..
 
+    build_python make.py build --dist=win
     build_pip install .
 
     QL_VERSION=$(MSYSTEM= build_python -c \
@@ -268,7 +270,7 @@ function cleanup_install {
     rm -f "${MINGW_ROOT}"/lib/gstreamer-1.0/libgstfaac.dll
     rm -f "${MINGW_ROOT}"/lib/gstreamer-1.0/libgstschro.dll
     rm -f "${MINGW_ROOT}"/lib/gstreamer-1.0/libgstcacasink.dll
-    # Crashes often on Windows maschines
+    # Crashes often on Windows machines
     rm -f "${MINGW_ROOT}"/lib/gstreamer-1.0/libgstamfcodec.dll
 
     rm -f "${MINGW_ROOT}"/bin/libBulletCollision.dll
@@ -358,12 +360,12 @@ function build_msix_installer {
         for size in {44,50,150}; do
             for scale in {100,125,150,200,400}; do
                 scaled_size=$(( (${size}*${scale}+100/2)/100 ))
-                rsvg-convert -w ${scaled_size} -h ${scaled_size} -o assets/gajim${size}x${size}.scale-${scale}.png ${DIR}/../gajim/data/icons/hicolor/scalable/apps/org.gajim.Gajim.svg
+                rsvg-convert -w ${scaled_size} -h ${scaled_size} -o assets/gajim${size}x${size}.scale-${scale}.png ${DIR}/../gajim/data/icons/hicolor/scalable/apps/gajim.svg
                 echo "\"assets/gajim${size}x${size}.scale-${scale}.png\" \"assets/gajim${size}x${size}.scale-${scale}.png\"" >> filemapping.txt
             done
         done
         for size in {16,24,32,48,256}; do
-            rsvg-convert -w ${size} -h ${size} -o assets/gajim44x44.targetsize-${size}.png ${DIR}/../gajim/data/icons/hicolor/scalable/apps/org.gajim.Gajim.svg
+            rsvg-convert -w ${size} -h ${size} -o assets/gajim44x44.targetsize-${size}.png ${DIR}/../gajim/data/icons/hicolor/scalable/apps/gajim.svg
             cp assets/gajim44x44.targetsize-${size}.png assets/gajim44x44.targetsize-${size}_altform-unplated.png
             cp assets/gajim44x44.targetsize-${size}.png assets/gajim44x44.targetsize-${size}_altform-lightunplated.png
             echo "\"assets/gajim44x44.targetsize-${size}.png\" \"assets/gajim44x44.targetsize-${size}.png\"" >> filemapping.txt
@@ -378,3 +380,13 @@ function build_msix_installer {
         makeappx bundle -d bundle/ -p Gajim.msixbundle -o
     )
 }
+
+function unpack_msixbundle {
+    (
+        cd ${BUILD_ROOT}
+        mkdir -p "${BUILD_ROOT}"/unpack
+        makeappx unbundle -p Gajim.msixbundle -d "${BUILD_ROOT}"/unpack
+        makeappx unpack -p "${BUILD_ROOT}"/unpack/Gajim_x64.msix -d "${BUILD_ROOT}"/unpack/Gajim
+        echo Unpacked msixbundle to "${BUILD_ROOT}"/unpack/Gajim
+    )
+}
